@@ -16,7 +16,16 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-/* $Id: dic.h,v 1.15 2000/12/12 01:48:39 antoine Exp $ */
+/* $Id: dic.h,v 1.1 2004/04/08 09:43:06 afrab Exp $ */
+
+/*!
+ *  \file dic.h
+ *  \brief  Dictionnaire sous forme de Dawg
+ *  \long
+ *  \author Antoine Fraboulet
+ *  \date   2002
+ *  \version 1
+ */
 
 #ifndef _DIC_H_
 #define _DIC_H_
@@ -35,7 +44,18 @@ typedef unsigned int uint_t;
    * 
    *************************/
 
-int    Dic_load   (Dictionary*,const char*);
+    /**
+     * Cration et chargement d'un dictionnaire
+     * @param dic : pointeur
+     * @param path : chemin
+     * @return 0 ok, 1 erreur
+     */
+int    Dic_load   (Dictionary* dic,const char* path);
+
+    /**
+     * Dtruit un doctionnaire
+     *
+     */
 int    Dic_destroy(Dictionary);
 
   /*************************
@@ -46,6 +66,7 @@ char   Dic_chr (Dictionary,uint_t);
 int    Dic_last(Dictionary,uint_t);
 int    Dic_word(Dictionary,uint_t);
 
+
 uint_t Dic_root(Dictionary);
 uint_t Dic_next(Dictionary,uint_t);
 uint_t Dic_succ(Dictionary,uint_t);
