@@ -16,67 +16,44 @@
 /* along with this program; if not, write to the Free Software               */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-/* $Id: configdb.cc,v 1.14 2000/12/12 01:50:40 antoine Exp $ */
+/* $Id: configdb.cc,v 1.1 2004/04/08 09:43:06 afrab Exp $ */
 
+#include <iostream>
 #include "ewx.h"
 #include "configdb.h"
-#include "wx/fontdlg.h"
 #include "wx/colordlg.h"
+#include "wx/fontdlg.h"
+#include "wx/settings.h" 
+
+using namespace std;
 
 #define DIM 200
 #define PREFIX  "/"
 
-#define DICPATH PREFIX"Dictionnaire/Chemin"
-#define DICNAME PREFIX"Dictionnaire/Nom"
+#define DICPATH  PREFIX"Fichiers/Dictionnaire_Chemin"
+#define DICNAME  PREFIX"Fichiers/Dictionnaire_Nom"
+#define TILEPATH PREFIX"Fichiers/Lettres_Chemin"
+#define TILENAME PREFIX"Fichiers/Lettres_Nom"
 
 ///////////////////////////
 //
 // Print
 //
 ///////////////////////////
-#define ORIENT  PREFIX"Print/Page/Orientation"
-#define MARGINX PREFIX"Print/Page/MargeGauche"
-#define MARGINY PREFIX"Print/Page/MargeHaute"
+#define ORIENT  PREFIX"Print/Page_Orientation"
+#define MARGINX PREFIX"Print/Page_MargeGauche"
+#define MARGINY PREFIX"Print/Page_MargeHaute"
 
 #define HNAME   PREFIX"Print/Header/Nom/"
-#define HFONT   PREFIX"Print/Header/Fonte/"
 #define HDIM    PREFIX"Print/Header/Dimensions/"
 #define HJUST   PREFIX"Print/Header/Justification/"
 #define HSPACE  PREFIX"Print/Header/Espacement/"
 
-#define TFONT   PREFIX"Print/Text/Fonte/"
 #define TDIM    PREFIX"Print/Text/Dimensions/"
 #define TJUST   PREFIX"Print/Text/Justification/"
 #define TSPACE  PREFIX"Print/Text/Espacement/"
 
-///////////////////////////
-//
-// Board Drawing
-//
-///////////////////////////
-
-#define BFONT              PREFIX"Board/Fonte/"
-#define BCOLOURLINES       PREFIX"Board/Couleurs/Lignes/"
-#define BCOLOURWX2         PREFIX"Board/Couleurs/MotsX2/"
-#define BCOLOURWX3         PREFIX"Board/Couleurs/MotsX3/"
-#define BCOLOURLX2         PREFIX"Board/Couleurs/LettresX2/"
-#define BCOLOURLX3         PREFIX"Board/Couleurs/LettresX3/"
-#define BCOLOURBACKGROUND  PREFIX"Board/Couleurs/fond/"
-#define BCOLOURLETTERS     PREFIX"Board/Couleurs/lettres/"
-#define BCOLOURTESTLETTERS PREFIX"Board/Couleurs/LettresPlacee/"
-
-///////////////////////////
-//
-// Frames
-//
-///////////////////////////
-#define FRAMEDIM  PREFIX"Frames/Dimensions/"
-#define FRAMEPOS  PREFIX"Frames/Positions/"
-#define FRAMEFONT PREFIX"Frames/Fontes/"
-#define SFONT     FRAMEFONT"Search/"
-
-
-#define MISC      PREFIX"Divers/"
+#define MISC    PREFIX"Divers/"
 
 ConfigDB::ConfigDB()
 {
@@ -114,23 +91,57 @@ long ConfigDB::Read(const wxString& key, long def)
   return res;
 }
 
+#define FPOINTSIZE ".PointSize"
+#define FFAMILY    ".Family"
+#define FSTYLE     ".Style"
+#define FWEIGHT    ".Weight"
+#define FUNDERLINE ".Underline"
+#define FFACENAME  ".FaceName"
+#define FENCODING  ".Encoding"
+
 wxFont ConfigDB::Read(const wxString& key, wxFont def)
 {
-  return wxFont(Read(key + "Taille",(long)def.GetPointSize()),
-		Read(key + "Famille",(long)def.GetFamily()),
-		Read(key + "Style",(long)def.GetStyle()),
-		Read(key + "Poids",(long)def.GetWeight()),
-		Read(key + "Souligne",(long)def.GetUnderlined()));
+  return wxFont(Read(key + FPOINTSIZE,(long)def.GetPointSize()),
+		Read(key + FFAMILY   ,(long)def.GetFamily()),
+		Read(key + FSTYLE    ,(long)def.GetStyle()),
+		Read(key + FWEIGHT   ,(long)def.GetWeight()),
+		Read(key + FUNDERLINE,(long)def.GetUnderlined()),
+		ReadStr(key + FFACENAME ,def.GetFaceName())
+		//,Read(key + FENCODING ,def.GetDefaultEncoding())
+		);
 }
 
+void ConfigDB::Write(const wxString& key, wxFont font)
+{
+  pConfig->Write(key + FPOINTSIZE,(long)font.GetPointSize());
+  pConfig->Write(key + FFAMILY   ,(long)font.GetFamily());
+  pConfig->Write(key + FSTYLE    ,(long)font.GetStyle());
+  pConfig->Write(key + FWEIGHT   ,(long)font.GetWeight());
+  pConfig->Write(key + FUNDERLINE,(long)font.GetUnderlined()); 
+  pConfig->Write(key + FFACENAME ,font.GetFaceName());
+  //pConfig->Write(key + FENCODING ,font.GetDefaultEncoding());
+}
+
+#define CR ".R"
+#define CG ".G"
+#define CB ".B"
+
 wxColour ConfigDB::Read(const wxString& key, wxColour def)
 {
-  return wxColour(Read(key + "R",(long)def.Red()),
-		  Read(key + "G",(long)def.Green()),
-		  Read(key + "B",(long)def.Blue()));
+  return wxColour(Read(key + CR,(long)def.Red()),
+		  Read(key + CG,(long)def.Green()),
+		  Read(key + CB,(long)def.Blue()));
 }
 
-wxString ConfigDB::ReadS(const wxString& key, wxString def)
+
+void ConfigDB::Write(const wxString& key, wxColour colour)
+{
+  pConfig->Write(key + CR,(long)colour.Red());
+  pConfig->Write(key + CG, (long)colour.Green());
+  pConfig->Write(key + CB, (long)colour.Blue());
+}
+
+wxString ConfigDB::ReadStr(const wxString& key, wxString def)
 {
   wxString res;
 
@@ -163,23 +174,8 @@ void ConfigDB::Write(const wxString& key, long val)
   pConfig->Write(key,val);
 }
 
-void ConfigDB::Write(const wxString& key, wxFont font)
-{
-  pConfig->Write(key + "Taille",(long)font.GetPointSize());
-  pConfig->Write(key + "Famille",(long)font.GetFamily());
-  pConfig->Write(key + "Style",(long)font.GetStyle());
-  pConfig->Write(key + "Poids",(long)font.GetWeight());
-  pConfig->Write(key + "Souligne",(long)font.GetUnderlined()); 
-}
 
-void ConfigDB::Write(const wxString& key, wxColour colour)
-{
-  pConfig->Write(key + "R",(long)colour.Red());
-  pConfig->Write(key + "G", (long)colour.Green());
-  pConfig->Write(key + "B", (long)colour.Blue());
-}
-
-void ConfigDB::WriteS(const wxString& key, wxString str)
+void ConfigDB::Write(const wxString& key, wxString str)
 {
   pConfig->Write(key,str);
 }
@@ -192,18 +188,34 @@ void ConfigDB::WriteS(const wxString& key, wxString str)
 
 wxString ConfigDB::getDicPath()
 {
-  return ReadS(DICPATH,wxString(""));
+  return ReadStr(DICPATH,wxString("//"));
 }
 
 wxString ConfigDB::getDicName()
 {
-  return ReadS(DICNAME,wxString(""));
+  return ReadStr(DICNAME,wxString("Aucun Dictionnaire"));
+}
+
+wxString ConfigDB::getTilePath()
+{
+  return ReadStr(TILEPATH,wxString("//"));
+}
+
+wxString ConfigDB::getTileName()
+{
+  return ReadStr(TILENAME,wxString(""));
 }
 
 void ConfigDB::setDicPath(wxString dpath, wxString dname)
 {
-  WriteS(DICPATH,dpath);
-  WriteS(DICNAME,dname);
+  Write(DICPATH,dpath);
+  Write(DICNAME,dname);
+}
+
+void ConfigDB::setTilePath(wxString dpath, wxString dname)
+{
+  Write(TILEPATH,dpath);
+  Write(TILENAME,dname);
 }
 
 ////////////////////////////////////////////////////////
@@ -300,11 +312,11 @@ wxString ConfigDB::getNameH(int i)
   wxString res;
   switch (i) 
     {
-    case 0: res = ReadS(wxString(HNAME)+wxString("1"),wxString("Num")); break;
-    case 1: res = ReadS(wxString(HNAME)+wxString("2"),wxString("Tirage")); break;
-    case 2: res = ReadS(wxString(HNAME)+wxString("3"),wxString("Solution")); break;
-    case 3: res = ReadS(wxString(HNAME)+wxString("4"),wxString("Pos")); break;
-    case 4: res = ReadS(wxString(HNAME)+wxString("5"),wxString("Pts")); break;
+    case 0: res = ReadStr(wxString(HNAME)+wxString("1"),wxString("Num")); break;
+    case 1: res = ReadStr(wxString(HNAME)+wxString("2"),wxString("Tirage")); break;
+    case 2: res = ReadStr(wxString(HNAME)+wxString("3"),wxString("Solution")); break;
+    case 3: res = ReadStr(wxString(HNAME)+wxString("4"),wxString("Pos")); break;
+    case 4: res = ReadStr(wxString(HNAME)+wxString("5"),wxString("Pts")); break;
     default: res = ""; break;
   }
   return res;
@@ -314,7 +326,7 @@ void ConfigDB::setNameH(int i, wxString str)
 {
   wxString key;
   key << HNAME << (i+1);
-  WriteS(key, str);
+  Write(key, str);
 }
 
 ////////////////////////////////////////////////////////
@@ -350,12 +362,12 @@ wxString ConfigDB::JustToStr(enum Justif j)
 
 enum Justif ConfigDB::getJustif(const wxString& key)
 {
-  return StrToJust(ReadS(key,wxString("gauche")));
+  return StrToJust(ReadStr(key,wxString("gauche")));
 }
 
 void ConfigDB::setJustif(const wxString& key, enum Justif j)
 {
-  WriteS(key,JustToStr(j));
+  Write(key,JustToStr(j));
 }
 
 enum Justif ConfigDB::getJustifH(int i)
@@ -440,48 +452,29 @@ wxFont ConfigDB::ChooseFont(wxFrame* frame,wxFont initfont)
   return retfont;
 }
 
-#define HFONTDEF wxFont(12, wxSWISS, wxNORMAL, wxBOLD)
-#define TFONTDEF wxFont(10, wxSWISS, wxNORMAL, wxNORMAL)
-#define BFONTDEF wxFont(10, wxSWISS, wxNORMAL, wxBOLD)
-#define SFONTDEF wxFont(12, wxMODERN, wxNORMAL, wxNORMAL)
+#define FHEADERDEF wxFont(12, wxSWISS, wxNORMAL, wxBOLD)
+#define FTEXTDEF wxFont(10, wxSWISS, wxNORMAL, wxNORMAL)
 
-#define SETFONT(NAME,KEY)       \
-void ConfigDB::NAME(wxFont f)   \
-{                               \
-  Write(KEY,f);                 \
-}                      
-
-SETFONT(setFontGameHead,HFONT)
-SETFONT(setFontGameText,TFONT)
-SETFONT(setFontBoard,BFONT)
-SETFONT(setFontSearch,SFONT)
-
-#define GETFONT(NAME,KEY,DEF)  \
-wxFont ConfigDB::NAME()        \
-{                              \
-  return Read(KEY,DEF);        \
-}
-
-GETFONT(getFontGameHead,HFONT,HFONTDEF)
-GETFONT(getFontGameText,TFONT,TFONTDEF)
-GETFONT(getFontBoard,BFONT,BFONTDEF)
-GETFONT(getFontSearch,SFONT,SFONTDEF)
-
-/*
-wxFont ConfigDB::getFont(wxString classname)
+void ConfigDB::setFontDefault()
 {
-  wxString key;
-  key = wxString(FRAMEFONT) + classname + wxString("/");
-  return Read(key,wxFont(12,wxMODERN,wxNORMAL,wxNORMAL));
-}
+  wxFont fsys;
+  fsys = wxSystemSettings::GetSystemFont(wxSYS_DEFAULT_GUI_FONT);
 
-void ConfigDB::setFont(wxString classname, wxFont font)
+  setFont(BOARDFONT ,fsys);
+  setFont(LISTFONT  ,fsys);
+  setFont(PRINTHFONT,FHEADERDEF);
+  setFont(PRINTTFONT,FTEXTDEF);
+}  
+
+void ConfigDB::setFont(wxString key, wxFont font)
 {
-  wxString key;
-  key = wxString(FRAMEFONT) + classname + wxString("/");
   Write(key,font);
 }
-*/
+
+wxFont ConfigDB::getFont(wxString key)
+{
+  return Read(key,wxFont(12,wxMODERN,wxNORMAL,wxNORMAL));
+}
 
 ////////////////////////////////////////////////////////
 //
@@ -512,46 +505,28 @@ wxColour ConfigDB::ChooseColour(wxFrame* frame,wxColour initcolour)
 #define LETTDEF    wxColour(  0,  0,  0)
 #define TSTLETTDEF wxColour(  0,  0,  0)
 
-void ConfigDB::setColourBoardDefault()
+void ConfigDB::setColourDefault()
 {
-  Write(BCOLOURLINES,LINESDEF);
-  Write(BCOLOURWX2,WX2DEF);
-  Write(BCOLOURWX3,WX3DEF);
-  Write(BCOLOURLX2,LX2DEF);
-  Write(BCOLOURLX3,LX3DEF);
-  Write(BCOLOURBACKGROUND,BACKDEF);
-  Write(BCOLOURLETTERS,LETTDEF);
+  setColour(wxString(BCOLOURLINES),LINESDEF);
+  setColour(wxString(BCOLOURWX2),WX2DEF);
+  setColour(wxString(BCOLOURWX3),WX3DEF);
+  setColour(wxString(BCOLOURLX2),LX2DEF);
+  setColour(wxString(BCOLOURLX3),LX3DEF);
+  setColour(wxString(BCOLOURBACKGROUND),BACKDEF);
+  setColour(wxString(BCOLOURLETTERS),LETTDEF);
 }
 
-#define SETCOLOUR(NAME,KEY)        \
-void ConfigDB::NAME(wxColour col)  \
-{                                  \
-  Write(KEY,col);                  \
+void
+ConfigDB::setColour(wxString key, wxColour col)
+{
+  Write(key,col);
 }
 
-SETCOLOUR(setColourBoardWx2,BCOLOURWX2)
-SETCOLOUR(setColourBoardWx3,BCOLOURWX3)
-SETCOLOUR(setColourBoardLx2,BCOLOURLX2)
-SETCOLOUR(setColourBoardLx3,BCOLOURLX3)
-SETCOLOUR(setColourBoardLines,BCOLOURLINES)
-SETCOLOUR(setColourBoardBackground,BCOLOURBACKGROUND)
-SETCOLOUR(setColourBoardLetters,BCOLOURLETTERS)
-SETCOLOUR(setColourBoardTestLetters,BCOLOURTESTLETTERS)
-
-#define GETCOLOUR(NAME,KEY,DEFAULT) \
-wxColour ConfigDB::NAME()           \
-{                                   \
-  return Read(KEY,DEFAULT);         \
-}                                       
-
-GETCOLOUR(getColourBoardLines,BCOLOURLINES,LINESDEF)
-GETCOLOUR(getColourBoardWx2,BCOLOURWX2,WX2DEF)
-GETCOLOUR(getColourBoardWx3,BCOLOURWX3,WX3DEF)
-GETCOLOUR(getColourBoardLx2,BCOLOURLX2,LX2DEF)
-GETCOLOUR(getColourBoardLx3,BCOLOURLX3,LX3DEF)
-GETCOLOUR(getColourBoardBackground,BCOLOURBACKGROUND,BACKDEF)
-GETCOLOUR(getColourBoardLetters,BCOLOURLETTERS,LETTDEF)
-GETCOLOUR(getColourBoardTestLetters,BCOLOURTESTLETTERS,TSTLETTDEF)
+wxColour
+ConfigDB::getColour(wxString key)
+{
+  return Read(key,wxColour(0,0,0));
+}
 
 ////////////////////////////////////////////////////////
 //
@@ -584,7 +559,7 @@ long ConfigDB::getOrientation()
   long res;
   wxString str;
   
-  str = ReadS(ORIENT,"paysage");
+  str = ReadStr(ORIENT,"paysage");
   if (str.CmpNoCase("portrait") == 0)
     res = wxPORTRAIT;
   else if (str.CmpNoCase("paysage") == 0)
@@ -598,9 +573,9 @@ void ConfigDB::setOrientation(long o)
 {
   switch (o) 
     {
-    case wxLANDSCAPE: WriteS(ORIENT,wxString("paysage")); break;
+    case wxLANDSCAPE: Write(ORIENT,wxString("paysage")); break;
     case wxPORTRAIT: // fall through
-    default: WriteS(ORIENT,wxString("portrait")); break;
+    default: Write(ORIENT,wxString("portrait")); break;
     }
 }
 
@@ -645,33 +620,111 @@ void ConfigDB::setPrintLineScale(float s)
 //
 ////////////////////////////////////////////////////////
 
-wxSize ConfigDB::getFrameDim(wxString frame)
+#define PX "/x"
+#define PY "/y"
+#define SW "/w"
+#define SH "/h"
+#define SHOW "/show"
+
+#define CONFIG_DEFAULT_X 150L
+#define CONFIG_DEFAULT_Y 150L
+#define CONFIG_DEFAULT_W 150L
+#define CONFIG_DEFAULT_H 200L
+
+wxPoint ConfigDB::getFramePos(wxString frame)
 {
-  wxString keyX(FRAMEDIM + frame + "/x");
-  wxString keyY(FRAMEDIM + frame + "/y");
-  return wxSize(Read(keyX,150L),Read(keyY,200L));
+  wxPoint pos;
+  wxString keyX(frame + PX);
+  wxString keyY(frame + PY);
+  pos.x = Read(keyX,CONFIG_DEFAULT_X);
+  pos.y = Read(keyY,CONFIG_DEFAULT_Y);
+#ifdef FRAME_TRACE
+  cerr << "configdb::getFramePos  " << frame 
+       << " \tx:" << pos.x << " y:" << pos.y << endl;
+#endif
+  return pos;
 }
 
-void ConfigDB::setFrameDim(wxString frame, wxSize size)
+void ConfigDB::setFramePos(wxString frame, wxPoint pos)
 {
-  wxString keyX(FRAMEDIM + frame + "/x");
-  wxString keyY(FRAMEDIM + frame + "/y");
+#ifdef FRAME_TRACE
+  cerr << "configdb::setFramePos  " << frame 
+       << " \tx:" << pos.x << " y:" << pos.y << endl;
+#endif
+  wxString keyX(frame + PX);
+  wxString keyY(frame + PY);
+  Write(keyX,(long)pos.x);
+  Write(keyY,(long)pos.y);
+}
+
+wxSize ConfigDB::getFrameSize(wxString frame)
+{
+  wxSize size;
+  wxString keyX(frame + SW);
+  wxString keyY(frame + SH);
+  size.x = Read(keyX,CONFIG_DEFAULT_W);
+  size.y = Read(keyY,CONFIG_DEFAULT_H);
+#ifdef FRAME_TRACE
+  cerr << "configdb::getFrameSize " << frame 
+       << " \tw:" << size.x << " h:" << size.y << endl;
+#endif  
+  return size;
+}
+
+void ConfigDB::setFrameSize(wxString frame, wxSize size)
+{
+#ifdef FRAME_TRACE
+  cerr << "configdb::setFrameSize " << frame 
+       << " \tw:" << size.x << " h:" << size.y << endl;
+#endif
+  wxString keyX(frame + SW);
+  wxString keyY(frame + SH);
   Write(keyX,(long)size.x);
   Write(keyY,(long)size.y);
 }
 
-
-wxSize ConfigDB::getMainFrameDim()
+int ConfigDB::getFrameShow(wxString frame)
 {
-  wxString frame = "eliot";
-  wxString keyX(FRAMEDIM + frame + "/x");
-  wxString keyY(FRAMEDIM + frame + "/y");
-  return wxSize(Read(keyX,640L),Read(keyY,450L));
+  wxString key(frame + SHOW);
+  return Read(key,0L);
 }
 
-void ConfigDB::setMainFrameDim(wxSize s)
+void ConfigDB::setFrameShow(wxString frame, int s)
 {
-  setFrameDim(wxString("eliot"),s);
+  wxString key(frame + SHOW);
+  Write(key,(long)s);
+}
+
+void ConfigDB::setFrameDefault()
+{
+  setFrameSize(FRAMEBOARD ,wxSize(450,450));
+  setFrameSize(FRAMEVERIF ,wxSize(150,50));
+  setFrameSize(FRAMESEARCH,wxSize(350,300));
+  setFrameSize(FRAMEPLUS1 ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
+  setFrameSize(FRAMERACC  ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
+  setFrameSize(FRAMEBENJ  ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
+  setFrameSize(FRAMEBAG   ,wxSize(150,40));
+  setFrameSize(APPNAME    ,wxSize(410,200));
+
+  setFramePos(FRAMEBOARD  ,wxPoint(58,76));
+  setFramePos(FRAMEVERIF  ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
+  setFramePos(FRAMESEARCH ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
+  setFramePos(FRAMEPLUS1  ,wxPoint(490,300));
+  setFramePos(FRAMERACC   ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
+  setFramePos(FRAMEBENJ   ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
+  setFramePos(FRAMEBAG    ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
+  setFramePos(APPNAME     ,wxPoint(500,9));
+
+  setFrameShow(FRAMEBOARD ,1L);
+  setFrameShow(FRAMEVERIF ,0L);
+  setFrameShow(FRAMESEARCH,0L);
+  setFrameShow(FRAMEPLUS1 ,1L);
+  setFrameShow(FRAMERACC  ,0L);
+  setFrameShow(FRAMEBENJ  ,0L);
+  setFrameShow(FRAMEBAG   ,0L);
+#ifdef FRAME_TRACE
+  cerr << endl;
+#endif
 }
 
 ////////////////////////////////////////////////////////
@@ -713,3 +766,19 @@ bool ConfigDB::getRackChecking()
 // 
 //
 ////////////////////////////////////////////////////////
+
+#define INIT "/Initialized"
+
+void
+ConfigDB::setFirstDefault()
+{
+  if (Read(wxString(INIT),0L))
+    return;
+
+  setFontDefault();
+  setColourDefault();
+  setFrameDefault();
+
+  Write(wxString(INIT),1L);
+}
+
